@@ -1,6 +1,6 @@
 from rich import print
-from cmdcheatsheet.config.consts import ALT_STORE_LOCATION_CONF, ALT_STORE_NAME_CONF
-from cmdcheatsheet.shared.display import BLUE, GREEN
+from ..config.consts import ALT_STORE_LOCATION_CONF, ALT_STORE_NAME_CONF
+from ..shared.display import BLUE, GREEN
 
 
 def display_alt_store_list(alt_stores):
