@@ -7,8 +7,11 @@ __all__ = [
     'delete_command',
     'detailed_commands',
     'detailed_find_command',
+    'detailed_global_find_command',
     'display',
     'find_command',
+    'global_find_command',
+    'messages',
     'table_view_commands',
     'table_view_find_command',
     'update_command',
